from django.db import models


class AbstractAbout(models.Model):
    title = models.CharField(max_length=255)
    description = models.TextField()
    image = models.ImageField(upload_to='about/')

    class Meta:
        abstract = True
        verbose_name = "About"
        verbose_name_plural = "About"

    def __str__(self):
        return self.title


class About(AbstractAbout):
    pass



from django.views.generic import TemplateView

from .services import get_about


class AboutView(TemplateView):
    template_name = "djtools/about/about.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context['about'] = get_about()
        return context
